  ! constants
  real, parameter :: epsilon = 0.96          !surface emissivity [1]
  real, parameter :: a_v_min = 0.3           !albedo of vegetation [1]
  real, parameter :: a_v_max = 0.5           !albedo of vegetation [1]
  real, parameter :: a_b     = 0.5           !albedo of bare soil [1]
  real, parameter :: sigma   = 5.676e-8      !Stefan-Boltzmann constant [w.m-2.K-4]
  real, parameter :: k_1     = 0.41          !Von Karman constant [-]
  real, parameter :: tau_l   = 1*3.1536e7    !residence time of leaf
                                             !biomass [s]
  real, parameter :: tau_r   = 10*3.1536e7   !residence time of root
                                             !biomass [s]
  real, parameter :: tau_s   = 10*3.1536e7   !residence time of stem
                                             !biomass [s]
  real, parameter :: c_d     = 1013          !specific head capacity of dry air [J.kg-1.K-1]
  real, parameter :: c_v     = 2080          !specific head capacity of water vapor [J.kg-1.K-1]
  real, parameter :: e       = 0.622         !ratio of molecular weight of water1 to dry air [1]
  real, parameter :: l       = 2.45e6        !latent heat of vaporization [J.kg-1]
  real, parameter :: SLA     = 20.0          !Specific leaf area [m2/kgC]
  real, parameter :: zn      = 2.0           !height of wind measurments [m]
  real, parameter :: z0m     = 0.02          !roughness length for momentum [m]
  real, parameter :: z0h     = 0.002         !roughness length for heat [m]
  real, parameter :: z0q     = 0.002         !roughness length for moisture [m]
  real, parameter :: R       = 287           !specific gas constant [J.kg-1.k-1]
  real, parameter :: rho_w   = 1e3           !water density [kg.m-3]
  real, parameter :: g_soilmax = 0.02        !minimum soil evaporation conductance [s/m]
  real, parameter :: c_a     = 380           !ambient CO2 concentration [ppmv]
  real, parameter :: con_soil = 0.2          !soil heat conductivity [w.m-1.k-1]
  real, parameter :: rsCs    = 2e6           !heat capacity of soil [J.m-3.k-1]
  real, parameter :: rwCw    = 4.2e6         !heat capacity of water [J.m-3.k-1]
  real, parameter :: LAIref  = 6.0           !reference LAI [m2/m2]
  real, dimension(2), parameter :: z = (/0.02, 0.48/) !depth of soil layer [m]
  ! z(1): first soil layer; z(2) second soil layer
  real, parameter :: k       = 0.5           !parameter for fc calculation [-]
  real, parameter :: CAref   = 15.0          !reference crown area [m2]
  real, parameter :: ac      = 5.323         !parameter in Dmax-gm theme [-]
  real, parameter :: bc      = 0.8929        !parameter in Dmax-gm theme [-]
  real, parameter :: cc      = 2.8           !parameter in Dmax-gm theme [-]
  real, parameter :: dc      = 4.7           !parameter in Dmax-gm theme [-]
  real, parameter :: ec      = 7.0           !parameter in Dmax-gm theme [-]
  real, parameter :: Q10     = 2
  real, parameter :: Ma      = 18            !mocular of H2O []
  real, parameter :: Mv      = 29            !mocular of air []
  real, parameter :: b2      = 0.944         !foliage scattering coefficient []
  real, parameter :: Gr      = 0.5           !distribution of leaves
  real, parameter :: gv      = 9.81          !acceleration due to gravity [m/s2]
  real, parameter :: fu      = 0.2           !radiation parameter [1]

  real :: w(3) = (/0.88889,0.55556,0.55556/) !weights used in three-point
  !gaussian quadrature
  real :: x(3) = (/0.0,0.7746,-0.7746/)      !points used in three-point
  !gaussian quadrature 


  ! parameters changed with specific issues
  real, dimension(:), allocatable :: G_sat           !saturated conductivity [m.s-1]
  real, dimension(:), allocatable :: a_s             !soil texture parameter [m-1]
  real, dimension(:), allocatable :: l_s             !soil texture parameter [-]
  real, dimension(:), allocatable :: n_s             !soil texture parameter [-]
  real, dimension(:), allocatable :: sm_r            !residual soil moisture [m3.m-3]
  real, dimension(:), allocatable :: sm_sat          !saturated soil moisture [m3.m-3]
  real, dimension(:), allocatable :: f0_s            !unstressed factor [-]
  real, dimension(:), allocatable :: Am_max
  real, dimension(:), allocatable :: Dmax_x
  real, dimension(:), allocatable :: Dmax_n
  real, dimension(:), allocatable :: Dmax_s
  real, dimension(:), allocatable :: f2c
  real, dimension(:), allocatable :: gm_s
  real, dimension(:), allocatable :: Eps0
  real, dimension(:), allocatable :: c_rm            !maximum root biomass[kgC/m2]  
  real, dimension(:), allocatable :: al
  real, dimension(:), allocatable :: G_x             !CO2 compensation concentration [ppm]
  real, dimension(:), allocatable :: sm_cap          !volumetric water content at field capacity (medium) [m3.m-3]
  real, dimension(:), allocatable :: sm_pwp          !volumetric water content at wilting point (medium) [m3.m-3]
  real, dimension(:), allocatable :: gd              !sensitivity coefficient for the dependence of r_s on vpD [Pa-1]
  real, dimension(:), allocatable :: T1_g
  real, dimension(:), allocatable :: T2_g
  real, dimension(:), allocatable :: T1_A
  real, dimension(:), allocatable :: T2_A
  integer, parameter :: numSoil = 6        ! number of soil texture types
  integer, parameter :: numC3   = 2        ! number of crop types
  integer, parameter :: numVeg  = 4        ! number of vegetation types

  allocate(sm_sat(numSoil))
  allocate(sm_r(numSoil))
  allocate(G_sat(numSoil))
  allocate(a_s(numSoil))
  allocate(sm_cap(numSoil))
  allocate(sm_pwp(numSoil))
  allocate(l_s(numSoil))
  allocate(n_s(numSoil))
  allocate(f0_s(numVeg))
  allocate(Am_max(numVeg))      ![kgC/m2s]
  allocate(Dmax_n(numVeg))
  allocate(Dmax_x(numVeg))
  allocate(Dmax_s(numVeg))
  allocate(f2c(numVeg))
  allocate(gm_s(numVeg))
  allocate(Eps0(numVeg))        ![kgC/J]
  allocate(c_rm(numVeg))
  allocate(al(numVeg))
  allocate(G_x(numVeg))
  allocate(gd(numVeg))
  allocate(T1_g(numVeg))
  allocate(T2_g(numVeg))
  allocate(T1_A(numVeg))
  allocate(T2_A(numVeg))

  ! settings soil texture parameters
  !            1Coarse,   2Medium, 3Medium fine, 4Fine,  5Very fine, 6Organic
  sm_sat  = (/0.403,   0.439,   0.430,   0.52,    0.614,     0.766  /)
  sm_r    = (/0.011,   0.011,   0.011,   0.011,   0.011,     0.011  /)
  sm_cap  = (/0.242,   0.346,    0.382,   0.448,   0.541,     0.662  /)
  sm_pwp  = (/0.059,   0.151,   0.133,   0.279,   0.335,     0.267  /)
  G_sat   = (/6.94e-6, 1.16e-6, 0.26e-6, 2.87e-6, 1.74e-6,   0.93e-6/)
  a_s     = (/3.83,    3.14,    0.83,    3.67,    2.65,      1.3    /)
  l_s     = (/1.25,   -2.342,  -0.588,  -1.977,   2.5,       0.4    /)
  n_s     = (/1.38,    1.28,     1.25,   1.1,     1.1,       1.2    /)

  !             1.Def grass, 2.Off grass 3.Def woody 4.Off woody   : here grass is C4 grass
  f0_s      = (/0.6,       0.6,        0.606,      0.46/)
  Am_max    = (/4.64e-7,   4.64e-7,    4.9e-7,     4.9e-7/)
  Dmax_n    = (/0.055,     0.055,      0.0,        0.0/)
  Dmax_x    = (/0.3,       0.3,        0.0,        0.0/)
  f2c       = (/0.5,       0.5,        0.1,        0.6/)
  gm_s      = (/2.38e-3,   2.38e-3,    1.6e-3,     4.4e-3/)
  G_x       = (/2.8,       2.8,        42.,        42./)
  Eps0      = (/3.82e-9,   3.82e-9,    4.64e-9,    4.64e-9/)
  c_rm      = (/1.0,       1.0,        10.0,       10.0/)
  al        = (/5e-3,      5e-3,       0.65,       0.65/)
  T1_g      = (/13.0,      13.0,       5.0,        5.0/)
  T2_g      = (/36.0,      36.0,       36.0,       36.0/)
  T1_A      = (/13.0,      13.0,       8.0,        8.0/)
  T2_A      = (/38.0,      38.0,       38.0,       38.0/)
 
